parserFwk.pyparsing.NoMatch

Package parserFwk :: Module pyparsing :: Class NoMatch |
[frames | no frames]

## Type NoMatch

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       NoMatch

A token that will never match.

Method Summary
| `__init__(self)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__str__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `ignore`, `leaveWhitespace`, `normalizeParseActionArgs`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `skipIgnorables`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net